/*
 * Copyright (c) 2003, 2004 Taavi Hupponen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

/*
 * Created on 15.4.2004
 *
 * 2004-08-29 fixed namespaces -- hsivonen
 */
package fi.iki.hsivonen.xml;

import gnu.xml.pipeline.EventConsumer;
import gnu.xml.pipeline.EventFilter;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

/**
 * Grabs the contents of the title element to be returned later.
 * 
 * @author taavi
 *
 * 
 */
public class TitleGrabber extends EventFilter {

    /**
     * The XHTML namespace URI
     */
    private final static String XHTML_NS = "http://www.w3.org/1999/xhtml";
    
    private StringBuffer title;
    private boolean headOpen, titleOpen;

    public TitleGrabber(EventConsumer next) {
        super(next);
        setContentHandler(this);
        headOpen = false;
        titleOpen = false;
        title = new StringBuffer();
    }

    public String getTitle() {
        return title.toString();
    }

    public void endElement(String uri, String local, String qname) throws SAXException {
        if ("head".equals(local) && XHTML_NS.equals(uri)) {
            headOpen = false;
        } else if ("title".equals(local) && XHTML_NS.equals(uri)) {
            titleOpen = false;
        }

        super.endElement(uri, local, qname);

    }

    public void startElement(String uri, String local, String qname, Attributes attributes) throws SAXException {
        if ("head".equals(local) && XHTML_NS.equals(uri)) {
            headOpen = true;
        } else if ("title".equals(local) && XHTML_NS.equals(uri)) {
            titleOpen = true;
        }

        super.startElement(uri, local, qname, attributes);

    }

    public void characters(char[] arg0, int arg1, int arg2) throws SAXException {
        if (headOpen && titleOpen) {
            title.append(arg0, arg1, arg2);
        }
        super.characters(arg0, arg1, arg2);
    }

}
