/*
 * Copyright (c) 2003, 2004 Henri Sivonen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

package fi.iki.hsivonen.template;
import java.io.IOException;

/**
 * Items which provide dates for formatting by the <code>TemplateEngine</code>
 * need to implement this interface.
 *
 * @version $Id: DatedItem.java,v 1.5 2004/08/28 16:20:07 hsivonen Exp $
 * @author  hsivonen
 */
public interface DatedItem extends Item {

    /** 
     * Returns the <code>i</code>th extra date of this item or 
     * <code>null</code> if the date is unknown. 
     *
     * @return the code>i</code>th date of this item or <code>null</code> if unknown
     *
     * @throws IOException if an I/O error occurs
     * @throws DataSourceException if any other difficulty is encountered
     */
    public java.util.Date getDate(int i)
        throws DataSourceException, IOException;

}
