/*
 * Copyright (c) 2003, 2004 Henri Sivonen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

package fi.iki.hsivonen.template.test;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

/**
 *
 * @author  hsivonen
 */
public class DomBench {
    
    
    /** Creates a new instance of DomBench */
    public DomBench() {
    }
    
    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        try {
            byte[] testData;
            long totalTime = 0;
            int length;
            File f = new File(args[0]);
            FileInputStream in = new FileInputStream(f);
            
            length = (int)f.length();
            testData = new byte[length];
            if(in.read(testData) != length) {
                throw new IOException();
            }
            
            in.close();
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            factory.setNamespaceAware(true);
            factory.setExpandEntityReferences(true);
            factory.setCoalescing(true);
            factory.setIgnoringComments(true);
            factory.setIgnoringElementContentWhitespace(false);
            factory.setValidating(false);
            DocumentBuilder builder = factory.newDocumentBuilder();
            int iterations = Integer.parseInt(args[1]);
            for(int i = 0; i < iterations; i++) {
                InputStream is = new ByteArrayInputStream(testData);
                System.gc();
                long startTime = System.currentTimeMillis();
                builder.parse(is);
                long stopTime = System.currentTimeMillis();
                totalTime += stopTime - startTime;
                System.gc();
            }
            System.out.println((double)totalTime / (double)iterations);
        } catch(Exception e) {
            System.err.println(e);
        }
    }
    
}
