/*
 * Copyright (c) 2003, 2004 Jussi Koskela
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package fi.iki.hsivonen.webcache.front;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

public class DownloaderThread extends Thread {

    /** input stream from the content server */
    private InputStream in;

    /** cached file */
    private CachedFile cachedFile;

    /** stop flag */
    private volatile boolean stop;

    /**
     * Class constructor.
     * @param cf the cached file
     * @param in the input stream from the content server
     */
    public DownloaderThread(CachedFile cachedFile, InputStream in) {
        this.cachedFile = cachedFile;
        this.in = in;
        stop = false;
    }

    /**
     * Kills the downloader thread.
     */
    public void kill() {
        stop = true; 
    }


    /**
     * Runs the downloader thread.
     */
    public void run() {
        OutputStream out = null;
        try {
            int bufferSize = 8192;
            byte buffer[] = new byte[bufferSize];
            out = cachedFile.getOutputStream();
            while (!stop) {
                int read = in.read(buffer, 0, bufferSize);
                if (read != -1) {
                    if (cachedFile.requestDiskSpace(read)) {
                        // disk space available
                        out.write(buffer, 0, read);
                        out.flush();
                        cachedFile.notifyDiskWrite(read);
                    } else {
                        // no disk space available
                        throw new IOException("Out of disk space");
                    }
                } else {
                    FrontServer.debug("End of stream reached");
                    // end of stream
                    break;
                }
            }
            FrontServer.debug("Download stopped");
        } catch (IOException ioe) {
            stop = true;
            System.err.println(ioe);
        } finally {
            try {
                if (in != null) {
                    in.close();
                }
            } catch (IOException ioe) {
            }
            try {
                if (out != null) {
                    out.close();
                }
            } catch (IOException ioe) {
            }
            cachedFile.onFinishDownloading(stop);
        }
    }
}
